Alsa-Devel Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Rene Herman <rene.herman@keyaccess.nl>
To: Takashi Iwai <tiwai@suse.de>
Cc: alsa-devel@alsa-project.org
Subject: Re: Re: snd-es1968 (+ snd-cs4236) trouble
Date: Wed, 14 Dec 2005 05:55:13 +0100	[thread overview]
Message-ID: <439FA5B1.8000601@keyaccess.nl> (raw)
In-Reply-To: <439F2E13.7070405@keyaccess.nl>

[-- Attachment #1: Type: text/plain, Size: 529 bytes --]

Rene Herman wrote:

> I'll poke around some more to confirm the documentation was right about 
> the Legacy Audio bit. I see the SB-EMU can be set to 0x240 and that's 
> free here, so I'll try and see for which setting of the bit something 
> appears there.

Managed to already. Yes, confirmed, the documentation was right. snd-sb8 
actually loads for this emulation:

ALSA sound/isa/sb/sb_common.c:130: SB [0x240]: DSP chip found, version = 3.2

So anyways, the submitted patch, re-attached for convenience, was right.

Rene.



[-- Attachment #2: linux-2.6.14.3_es1968_tdma_la_iem.diff --]
[-- Type: text/plain, Size: 1726 bytes --]

--- linux-2.6.14.3-local-wc/sound/pci/es1968.c.orig	2005-12-13 07:25:47.000000000 +0100
+++ linux-2.6.14.3-local-wc/sound/pci/es1968.c	2005-12-13 07:26:04.000000000 +0100
@@ -176,7 +176,7 @@ MODULE_PARM_DESC(joystick, "Enable joyst
 
 /* Values for the ESM_LEGACY_AUDIO_CONTROL */
 
-#define ESS_ENABLE_AUDIO	0x8000
+#define ESS_DISABLE_AUDIO	0x8000
 #define ESS_ENABLE_SERIAL_IRQ	0x4000
 #define IO_ADRESS_ALIAS		0x0020
 #define MPU401_IRQ_ENABLE	0x0010
@@ -195,7 +195,7 @@ MODULE_PARM_DESC(joystick, "Enable joyst
 #define DMA_TDMA		0x0100
 #define DMA_PCPCI		0x0200
 #define POST_WRITE		0x0080
-#define ISA_TIMING		0x0040
+#define PCI_TIMING		0x0040
 #define SWAP_LR			0x0020
 #define SUBTR_DECODE		0x0002
 
@@ -2197,14 +2197,11 @@ static void snd_es1968_chip_init(es1968_
 	/* Config Reg A */
 	pci_read_config_word(pci, ESM_CONFIG_A, &w);
 
-	/*      Use TDMA for now. TDMA works on all boards, so while its
-	 *      not the most efficient its the simplest. */
 	w &= ~DMA_CLEAR;	/* Clear DMA bits */
-	w |= DMA_TDMA;		/* TDMA on */
 	w &= ~(PIC_SNOOP1 | PIC_SNOOP2);	/* Clear Pic Snoop Mode Bits */
 	w &= ~SAFEGUARD;	/* Safeguard off */
 	w |= POST_WRITE;	/* Posted write */
-	w |= ISA_TIMING;	/* ISA timing on */
+	w |= PCI_TIMING;	/* PCI timing on */
 	/* XXX huh?  claims to be reserved.. */
 	w &= ~SWAP_LR;		/* swap left/right 
 				   seems to only have effect on SB
@@ -2245,7 +2242,7 @@ static void snd_es1968_chip_init(es1968_
 
 	pci_read_config_word(pci, ESM_LEGACY_AUDIO_CONTROL, &w);
 
-	w &= ~ESS_ENABLE_AUDIO;	/* Disable Legacy Audio */
+	w |= ESS_DISABLE_AUDIO;	/* Disable Legacy Audio */
 	w &= ~ESS_ENABLE_SERIAL_IRQ;	/* Disable SIRQ */
 	w &= ~(0x1f);		/* disable mpu irq/io, game port, fm, SB */
 

  reply	other threads:[~2005-12-14  4:51 UTC|newest]

Thread overview: 10+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2005-12-10 20:13 snd-es1968 (+ snd-cs4236) trouble Rene Herman
2005-12-11  9:08 ` Sergey Vlasov
2005-12-11 15:16   ` Rene Herman
2005-12-12 11:58 ` Takashi Iwai
2005-12-12 22:53   ` Rene Herman
2005-12-13  7:09     ` Rene Herman
2005-12-13 11:04       ` Takashi Iwai
2005-12-13 20:24         ` Rene Herman
2005-12-14  4:55           ` Rene Herman [this message]
2005-12-14 12:00             ` Takashi Iwai

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=439FA5B1.8000601@keyaccess.nl \
    --to=rene.herman@keyaccess.nl \
    --cc=alsa-devel@alsa-project.org \
    --cc=tiwai@suse.de \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox